/*******************************************************************************
* File Name: Clkout.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Clkout.h"


/*******************************************************************************
* Function Name: Clkout_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Clkout_Write(uint8 value) 
{
    uint8 staticBits = (Clkout_DR & (uint8)(~Clkout_MASK));
    Clkout_DR = staticBits | ((uint8)(value << Clkout_SHIFT) & Clkout_MASK);
}


/*******************************************************************************
* Function Name: Clkout_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Clkout_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Clkout_0, mode);
}


/*******************************************************************************
* Function Name: Clkout_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Clkout_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Clkout_Read(void) 
{
    return (Clkout_PS & Clkout_MASK) >> Clkout_SHIFT;
}


/*******************************************************************************
* Function Name: Clkout_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Clkout_ReadDataReg(void) 
{
    return (Clkout_DR & Clkout_MASK) >> Clkout_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Clkout_INTSTAT) 

    /*******************************************************************************
    * Function Name: Clkout_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Clkout_ClearInterrupt(void) 
    {
        return (Clkout_INTSTAT & Clkout_MASK) >> Clkout_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
