/*******************************************************************************
* File Name: Interruptout.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Interruptout.h"


/*******************************************************************************
* Function Name: Interruptout_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Interruptout_Write(uint8 value) 
{
    uint8 staticBits = (Interruptout_DR & (uint8)(~Interruptout_MASK));
    Interruptout_DR = staticBits | ((uint8)(value << Interruptout_SHIFT) & Interruptout_MASK);
}


/*******************************************************************************
* Function Name: Interruptout_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Interruptout_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Interruptout_0, mode);
}


/*******************************************************************************
* Function Name: Interruptout_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Interruptout_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Interruptout_Read(void) 
{
    return (Interruptout_PS & Interruptout_MASK) >> Interruptout_SHIFT;
}


/*******************************************************************************
* Function Name: Interruptout_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Interruptout_ReadDataReg(void) 
{
    return (Interruptout_DR & Interruptout_MASK) >> Interruptout_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Interruptout_INTSTAT) 

    /*******************************************************************************
    * Function Name: Interruptout_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Interruptout_ClearInterrupt(void) 
    {
        return (Interruptout_INTSTAT & Interruptout_MASK) >> Interruptout_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
